@@ -26,12 +26,14 @@ public:
     Phonon::SeekSlider* getSeekSlider() { return seekSlider; }
     void readSettings();
     void writeSettings();
+    static void printHelp();
 
 public slots:
     void showMedia(SearchParams *params);
     void restore();
     void messageReceived(const QString &message);
     void quit();
+    void startToolbarSearch(QString query);
 
 protected:
     void changeEvent(QEvent *);
@@ -48,6 +50,7 @@ private slots:
     void showSearch();
     void visitSite();
     void donate();
+    void reportIssue();
     void about();
     void fullscreen();
     void updateUIForFullscreen();
@@ -77,11 +80,12 @@ private slots:
     void downloadsFinished();
     void toggleDownloads(bool show);
 
-    void startToolbarSearch(QString query);
     void floatOnTop(bool);
     void showActionInStatusBar(QAction*, bool show);
     void showStopAfterThisInStatusBar(bool show);
 
+    void hideMouse();
+
 private:
     void initPhonon();
     void createActions();
@@ -157,6 +161,8 @@ private:
     bool m_fullscreen;
     bool m_maximized;
 
+    QTimer *mouseTimer;
+
 };
 
 #endif
