@@ -8,7 +8,8 @@ class Constants {
 public:
 
     static const char *VERSION;
-    static const char *APP_NAME;
+    static const char *NAME;
+    static const char *UNIX_NAME;
     static const char *ORG_NAME;
     static const char *ORG_DOMAIN;
     static const char *WEBSITE;
