@@ -21,6 +21,7 @@ public:
     void setListModel(ListModel *listModel) {
         this->listModel = listModel;
     }
+    void showSnapshotPreview(QPixmap pixmap);
 
 signals:
     void doubleClicked();
@@ -31,7 +32,9 @@ protected:
     void mousePressEvent(QMouseEvent *event);
     void dragEnterEvent(QDragEnterEvent *event);
     void dropEvent(QDropEvent *event);
-    void mouseMoveEvent(QMouseEvent *event);
+
+private slots:
+    void hideSnapshotPreview();
 
 private:
     QStackedLayout *stackedLayout;
@@ -39,6 +42,7 @@ private:
     LoadingWidget *loadingWidget;
     ListModel *listModel;
     QLabel *messageLabel;
+    QLabel *snapshotPreview;
 
 };
 
